@@ -1,6 +1,7 @@
 import logging
 import os
 
+
 class Logger:
 
     def __init__(self, header):
@@ -16,4 +17,10 @@ class Logger:
         self.logger.debug(self.header + msg, *args, **kwargs)
 
     def error(self, msg, *args, **kwargs):
-        self.logger.error(self.header + msg, *args, **kwargs)
\ No newline at end of file
+        self.logger.error(self.header + msg, *args, **kwargs)
+
+    def warning(self, msg, *args, **kwargs):
+        self.logger.error(self.header + msg, *args, **kwargs)
+
+    def critical(self, msg, *args, **kwargs):
+        self.logger.error(self.header + msg, *args, **kwargs)
