@@ -1,6 +1,6 @@
 import boto3
 from dnxdata.utils.utils import Utils
-from dnxdata.logger import info, error
+from dnxdata.logger import Logger
 from dnxdata.resource import glue_client
 
 
@@ -8,9 +8,11 @@ class Glue:
 
     def __init__(self):
         self.utils = Utils()
+        self.logger = Logger("DNX Glue => ")
 
     def get_job_glue(self, job_name, job_run_id):
-        info(
+
+        self.logger.info(
             "Starting _GetJobGlue job_name {},job_run_id {}"
             .format(
                 job_name,
@@ -20,7 +22,7 @@ class Glue:
 
         status = glue_client.get_job_run(JobName=job_name, RunId=job_run_id)
 
-        info(
+        self.logger.info(
             "Finishing _GetJobGlue status {}"
             .format(status)
         )
@@ -29,7 +31,7 @@ class Glue:
 
     def get_status_job_glue(self, job_name, job_run_id):
 
-        info(
+        self.logger.info(
             "Starting GetStatusJobGlue job_name {}, job_run_id {}"
             .format(
                 job_name,
@@ -39,7 +41,7 @@ class Glue:
         status = self.get_job_glue(job_name=job_name, job_run_id=job_run_id)
         state = status['JobRun']['JobRunState']
 
-        info(
+        self.logger.info(
             "Finishing GetStatusJobGlue Status {}"
             .format(state)
         )
@@ -48,7 +50,7 @@ class Glue:
 
     def get_msg_error_job_glue(self, job_name, job_run_id):
 
-        info(
+        self.logger.info(
             "Starting GetMsgErrorJobGlue job_name {}, job_run_id {}"
             .format(
                 job_name,
@@ -58,7 +60,7 @@ class Glue:
         status = self.get_job_glue(job_name=job_name, job_run_id=job_run_id)
         msg_error = status['JobRun']['ErrorMessage']
 
-        info(
+        self.logger.info(
             "Finishing GetMsgErrorJobGlue ErrorMessage {}"
             .format(msg_error)
         )
