@@ -1,15 +1,15 @@
 import pymysql
-from dnxdata.logger import info
+from dnxdata.logger import Logger
 
 
 class Mysql:
 
     def __init__(self):
-        pass
+        self.logger = Logger("DNX Mysql => ")
 
     def execute(self, connection_settings, script):
 
-        info(
+        self.logger.debug(
             "Starting Exec Query Mysql Script {}"
             .format(script)
         )
@@ -24,13 +24,13 @@ class Mysql:
             for row in cur:
                 result.append(list(row))
 
-        info("Return Mysql {}".format(result))
-        info("Finishing Exec Query Mysql")
+        self.logger.debug("Return Mysql {}".format(result))
+        self.logger.debug("Finishing Exec Query Mysql")
         return result
 
     def connection(self, connection_settings):
 
-        info("Starting Connection Mysql")
+        self.logger.debug("Starting Connection Mysql")
 
         conn = pymysql.connect(
             host=connection_settings.get("host"),
@@ -40,38 +40,39 @@ class Mysql:
             connect_timeout=5
         )
 
-        info("Finishing Connection Mysql")
+        self.logger.debug("Finishing Connection Mysql")
         return conn
 
     def get_primary_key(self, connection_settings, schema, table):
 
-        info(
+        self.logger.debug(
             "Starting get_primary_key schema {} table {}"
-            .format(schema, table)
+            .format(
+                schema,
+                table
+            )
         )
 
         select = """
         SELECT column_name
-          FROM information_schema.columns
+          FROM self.logger.information_schema.columns
           WHERE lower(table_schema) = "{}"
             AND lower(table_name) = "{}"
             AND COLUMN_KEY = "PRI"
           ORDER BY ORDINAL_POSITION """.format(schema.lower(), table.lower())
 
-        info(
-            "Select get_primary_key {}"
-            .format(select)
-        )
+        self.logger.debug("Select get_primary_key {}".format(select))
 
         result = self.execute(
             connection_settings=connection_settings,
             script=select
         )
 
-        # TODO Review logic
-        result = [x for x in result[0]]
+        result = []
+        for x in result[0]:
+            result.append(x)
 
-        info("Result {}".format(result))
-        info("Finishing get_primary_key")
+        self.logger.debug("Result {}".format(result))
+        self.logger.debug("Finishing get_primary_key")
 
         return result
